#########################################
sageodata_db Python package documentation
#########################################

Hello! This documentation is about the Python package sageodata_db. This package provides 
code to make it easier to access and use data stored in SA Geodata. 

.. toctree::
   :maxdepth: 5
   :caption: Contents:

   installation
   predefined-queries
   apidocs
   changelog

.. toctree::
   :caption: Other documentation
   
   Other versions <../index.html#http://>
   Other packages <../../index.html#http://>
